<?php

namespace SGalinski\SgNews\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\Domain\Model\FileReference;
use TYPO3\CMS\Extbase\DomainObject\AbstractEntity;
use TYPO3\CMS\Extbase\Persistence\Generic\LazyLoadingProxy;
use TYPO3\CMS\Extbase\Persistence\ObjectStorage;

/**
 * Abstract Category and news
 */
abstract class CategoryAndNews extends AbstractEntity {
	/**
	 * @var string
	 */
	protected $navTitle = '';

	/**
	 * @var string
	 */
	protected $title = '';

	/**
	 * @var string
	 */
	protected $subtitle = '';

	/**
	 * @var int
	 */
	protected $sorting = 0;

	/**
	 * @TYPO3\CMS\Extbase\Annotation\ORM\Lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $teaser1Image;

	/**
	 * @TYPO3\CMS\Extbase\Annotation\ORM\Lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $teaser2Image;

	/**
	 * @TYPO3\CMS\Extbase\Annotation\ORM\Lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $ogImage;

	/**
	 * @TYPO3\CMS\Extbase\Annotation\ORM\Lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $twitterImage;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->teaser1Image = new ObjectStorage();
		$this->teaser2Image = new ObjectStorage();
	}

	/**
	 * @param string $title
	 * @return void
	 */
	public function setTitle($title) {
		$this->title = $title;
	}

	/**
	 * @return string
	 */
	public function getTitle() {
		return $this->title;
	}

	/**
	 * @param string $navTitle
	 * @return void
	 */
	public function setNavTitle($navTitle) {
		$this->navTitle = $navTitle;
	}

	/**
	 * @return string
	 */
	public function getNavTitle() {
		return $this->navTitle;
	}

	/**
	 * @param string $subtitle
	 * @return void
	 */
	public function setSubtitle($subtitle) {
		$this->subtitle = $subtitle;
	}

	/**
	 * @return string
	 */
	public function getSubtitle() {
		return $this->subtitle;
	}

	/**
	 * @return string
	 */
	public function getSubtitleWithFallbackToTitle() {
		return ($this->subtitle !== '' ? $this->subtitle : $this->title);
	}

	/**
	 * @return ObjectStorage
	 */
	public function getTeaser1Image() {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		return $this->teaser1Image;
	}

	/**
	 * @param ObjectStorage $teaser1Images
	 * @return void
	 */
	public function setTeaser1Image(ObjectStorage $teaser1Images) {
		$this->teaser1Image = $teaser1Images;
	}

	/**
	 * @param FileReference $teaser1Image
	 * @return void
	 */
	public function addTeaser1Image(FileReference $teaser1Image) {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		$this->teaser1Image->attach($teaser1Image);
	}

	/**
	 * @param FileReference $teaser1Image
	 * @return void
	 */
	public function removeTeaser1Image(FileReference $teaser1Image) {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		$this->teaser1Image->detach($teaser1Image);
	}

	/**
	 * @return ObjectStorage
	 */
	public function getTeaser2Image() {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		return $this->teaser2Image;
	}

	/**
	 * @param ObjectStorage $teaser2Images
	 * @return void
	 */
	public function setTeaser2Image(ObjectStorage $teaser2Images) {
		$this->teaser2Image = $teaser2Images;
	}

	/**
	 * @param FileReference $teaser2Image
	 * @return void
	 */
	public function addTeaser2Image(FileReference $teaser2Image) {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		$this->teaser2Image->attach($teaser2Image);
	}

	/**
	 * @param FileReference $teaser2Image
	 * @return void
	 */
	public function removeTeaser2Image(FileReference $teaser2Image) {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		$this->teaser2Image->detach($teaser2Image);
	}

	/**
	 * @return ObjectStorage
	 */
	public function getOgImage() {
		if ($this->ogImage instanceof LazyLoadingProxy) {
			$this->ogImage->_loadRealInstance();
		}

		return $this->ogImage;
	}

	/**
	 * @param ObjectStorage $twitterImages
	 * @return void
	 */
	public function setOgImage(ObjectStorage $twitterImages) {
		$this->ogImage = $twitterImages;
	}

	/**
	 * @param FileReference $twitterImage
	 * @return void
	 */
	public function addOgImage(FileReference $twitterImage) {
		if ($this->ogImage instanceof LazyLoadingProxy) {
			$this->ogImage->_loadRealInstance();
		}

		$this->ogImage->attach($twitterImage);
	}

	/**
	 * @param FileReference $twitterImage
	 * @return void
	 */
	public function removeOgImage(FileReference $twitterImage) {
		if ($this->ogImage instanceof LazyLoadingProxy) {
			$this->ogImage->_loadRealInstance();
		}

		$this->ogImage->detach($twitterImage);
	}

	/**
	 * @return ObjectStorage
	 */
	public function getTwitterImage() {
		if ($this->twitterImage instanceof LazyLoadingProxy) {
			$this->twitterImage->_loadRealInstance();
		}

		return $this->twitterImage;
	}

	/**
	 * @param ObjectStorage $twitterImages
	 * @return void
	 */
	public function setTwitterImage(ObjectStorage $twitterImages) {
		$this->twitterImage = $twitterImages;
	}

	/**
	 * @param FileReference $ogImage
	 * @return void
	 */
	public function addTwitterImage(FileReference $ogImage) {
		if ($this->twitterImage instanceof LazyLoadingProxy) {
			$this->twitterImage->_loadRealInstance();
		}

		$this->twitterImage->attach($ogImage);
	}

	/**
	 * @param FileReference $ogImage
	 * @return void
	 */
	public function removeTwitterImage(FileReference $ogImage) {
		if ($this->twitterImage instanceof LazyLoadingProxy) {
			$this->twitterImage->_loadRealInstance();
		}

		$this->twitterImage->detach($ogImage);
	}

	/**
	 * @return int
	 */
	public function getSorting() {
		return $this->sorting;
	}

	/**
	 * @param int $sorting
	 */
	public function setSorting($sorting) {
		$this->sorting = (int) $sorting;
	}
}
