<?php

namespace SGalinski\SgNews\ViewHelpers\Backend;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgNews\ViewHelpers\AbstractViewHelper;
use TYPO3\CMS\Core\Imaging\Icon;
use TYPO3\CMS\Core\Imaging\IconFactory;
use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * Class IconViewHelper
 **/
class IconViewHelper extends AbstractViewHelper {
	/**
	 * Initialize the ViewHelper arguments
	 */
	public function initializeArguments() {
		parent::initializeArguments();
		$this->registerArgument('id', 'string', 'The id of the record', TRUE);
		$this->registerArgument('size', 'string', 'The size of the icon', FALSE, '');
		$this->registerArgument('overlayId', 'string', 'The overlay of the icon', FALSE);
	}

	/**
	 * Renders the icon for the specified identifier
	 * with the requested size option and overlay.
	 *
	 * @return string
	 * @throws \InvalidArgumentException
	 */
	public function render(): string {
		$id = trim($this->arguments['id']);
		$size = trim($this->arguments['size']);
		$overlayId = $this->arguments['overlayId'];
		switch ($size) {
			case 'small':
				$size = Icon::SIZE_SMALL;
				break;
			case 'large':
				$size = Icon::SIZE_LARGE;
				break;
			default:
				$size = Icon::SIZE_DEFAULT;
				break;
		}

		$iconFactory = GeneralUtility::makeInstance(IconFactory::class);
		return $iconFactory->getIcon($id, $size, $overlayId)->render();
	}
}
